@@ -219,21 +219,22 @@ String fallbacks[] = {
     "XEphem*INDIConfig*EDBValue.value: Mount.GOTOedb.edb",
     "XEphem*INDIConfig*EnableEDB.set: False",
     "XEphem*INDIConfig*EnableRADec.set: False",
+    "XEphem*INDIConfig*TelEOD.set: False",
     "XEphem*INDIConfig*GotoDecOffset.value: 0",
-    "XEphem*INDIConfig*GotoDecSlope.value: .0174532925",
+    "XEphem*INDIConfig*GotoDecSlope.value: .01745329251994329576",
     "XEphem*INDIConfig*GotoDecValue.value: Telescope.SetRADec2K.Dec",
     "XEphem*INDIConfig*GotoRAOffset.value: 0",
-    "XEphem*INDIConfig*GotoRASlope.value: .2617993875",
+    "XEphem*INDIConfig*GotoRASlope.value: .26179938779914943653",
     "XEphem*INDIConfig*GotoRAValue.value: Telescope.SetRADec2K.RA",
     "XEphem*INDIConfig*Host.value: localhost",
     "XEphem*INDIConfig*JDOffset.value: -2415020",
     "XEphem*INDIConfig*JDSlope.value: 1",
     "XEphem*INDIConfig*JDValue.value: Mount.Date.JD",
     "XEphem*INDIConfig*LatitudeOffset.value: 0",
-    "XEphem*INDIConfig*LatitudeSlope.value: .0174532925",
+    "XEphem*INDIConfig*LatitudeSlope.value: .01745329251994329576",
     "XEphem*INDIConfig*LatitudeValue.value: Mount.GEOGRAPHIC_COORD.LAT",
     "XEphem*INDIConfig*LongitudeOffset.value: 0",
-    "XEphem*INDIConfig*LongitudeSlope.value: .0174532925",
+    "XEphem*INDIConfig*LongitudeSlope.value: .01745329251994329576",
     "XEphem*INDIConfig*LongitudeValue.value: Mount.GEOGRAPHIC_COORD.LONG",
     "XEphem*INDIConfig*POSIXTMValue.value: Mount.Date.POSIX",
     "XEphem*INDIConfig*Port.value: 7624",
@@ -242,11 +243,11 @@ String fallbacks[] = {
     "XEphem*INDIConfig*PressureValue.value: Weather.WX.Pres",
     "XEphem*INDIConfig*Recenter.set: False",
     "XEphem*INDIConfig*SkyDecOffset.value: 0",
-    "XEphem*INDIConfig*SkyDecSlope.value: .0174532925",
+    "XEphem*INDIConfig*SkyDecSlope.value: .01745329251994329576",
     "XEphem*INDIConfig*SkyDecValue.value: Telescope.Pointing.Dec2K",
     "XEphem*INDIConfig*SkyMarker.set: False",
     "XEphem*INDIConfig*SkyRAOffset.value: 0",
-    "XEphem*INDIConfig*SkyRASlope.value: .2617993875",
+    "XEphem*INDIConfig*SkyRASlope.value: .26179938779914943653",
     "XEphem*INDIConfig*SkyRAValue.value: Telescope.Pointing.RA2K",
     "XEphem*INDIConfig*TemperatureOffset.value: 0",
     "XEphem*INDIConfig*TemperatureSlope.value: 1",
@@ -743,14 +744,16 @@ String fallbacks[] = {
     "XEphem*WCS.y: 10",
     "XEphem*WebDB*Pattern.value: ",
     "XEphem*WebDB*Search.set: False",
-    "XEphem*WebDB*URL0.value: http://celestrak.com/NORAD/elements/stations.txt",
-    "XEphem*WebDB*URL1.value: http://celestrak.com/NORAD/elements/science.txt",
-    "XEphem*WebDB*URL2.value: http://celestrak.com/NORAD/elements/tle-new.txt",
-    "XEphem*WebDB*URL3.value: http://celestrak.com/NORAD/elements/amateur.txt",
-    "XEphem*WebDB*URL4.value: https://www.minorplanetcenter.org/iau/Ephemerides/Comets/Soft03Cmt.txt",
-    "XEphem*WebDB*URL5.value: https://www.minorplanetcenter.org/iau/Ephemerides/CritList/Soft03CritList.txt",
-    "XEphem*WebDB*URL6.value: https://www.minorplanetcenter.org/iau/Ephemerides/Distant/Soft03Distant.txt",
-    "XEphem*WebDB*URL7.value: https://www.minorplanetcenter.org/iau/Ephemerides/Unusual/Soft03Unusual.txt",
+    "XEphem*WebDB*URL0.value: http://celestrak.org/NORAD/elements/stations.txt",
+    "XEphem*WebDB*URL1.value: http://celestrak.org/NORAD/elements/science.txt",
+    "XEphem*WebDB*URL2.value: http://celestrak.org/NORAD/elements/tle-new.txt",
+    "XEphem*WebDB*URL3.value: http://celestrak.org/NORAD/elements/amateur.txt",
+    "XEphem*WebDB*URL4.value: http://celestrak.org/NORAD/elements/visual.txt",
+    "XEphem*WebDB*URL5.value: https://www.minorplanetcenter.net/iau/Ephemerides/Comets/Soft03Cmt.txt",
+    "XEphem*WebDB*URL6.value: https://www.minorplanetcenter.net/iau/Ephemerides/CritList/Soft03CritList.txt",
+    "XEphem*WebDB*URL7.value: https://www.minorplanetcenter.net/iau/Ephemerides/Distant/Soft03Distant.txt",
+    "XEphem*WebDB*URL8.value: https://www.minorplanetcenter.net/iau/Ephemerides/Unusual/Soft03Unusual.txt",
+    "XEphem*WebDB*URL9.value:",
     "XEphem*WebDB.x: 200",
     "XEphem*WebDB.y: 200",
     "XEphem*WeekStart.Monday.set: False",
@@ -961,4 +964,4 @@ String fallbacks[] = {
     NULL
 };
 
-/* $Id: fallbacks.c,v 1.313 2013/01/14 04:02:19 ecdowney Exp $ */
+/* $Id: fallbacks.c,v 1.314 2021/12/14 19:10:39 ecdowney Exp $ */
